Welcome to zfit's documentation!
======================================

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   zfit.pdf
   zfit.func
   zfit.data
   zfit.minimize
   zfit.loss
   zfit.constraint
   zfit.ztf
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
